@@ -1,7 +1,7 @@
 #include "battery.h"
-#include "common/io/io.h"
-#include "util/FFstrbuf.h"
-#include "util/stringUtils.h"
+#include "common/io.h"
+#include "common/FFstrbuf.h"
+#include "common/stringUtils.h"
 
 #include <prop/prop_array.h>
 #include <prop/prop_bool.h>
@@ -16,8 +16,8 @@
 
 const char* ffDetectBattery(FF_MAYBE_UNUSED FFBatteryOptions* options, FFlist* results)
 {
-    FF_AUTO_CLOSE_FD int fd = open(_PATH_SYSMON, O_RDONLY);
-    if (fd < 0) return "open(_PATH_SYSMON, O_RDONLY) failed";
+    FF_AUTO_CLOSE_FD int fd = open(_PATH_SYSMON, O_RDONLY | O_CLOEXEC);
+    if (fd < 0) return "open(_PATH_SYSMON, O_RDONLY | O_CLOEXEC) failed";
 
     prop_dictionary_t root = NULL;
     if (prop_dictionary_recv_ioctl(fd, ENVSYS_GETDICTIONARY, &root) < 0)
