@@ -1,6 +1,6 @@
 #include "diskio.h"
-#include "util/stringUtils.h"
-#include "util/mallocHelper.h"
+#include "common/stringUtils.h"
+#include "common/mallocHelper.h"
 
 #include <sys/disk.h>
 #include <sys/sysctl.h>
@@ -13,7 +13,7 @@ const char* ffDiskIOGetIoCounters(FFlist* result, FFDiskIOOptions* options)
         return "sysctl({HW_DISKSTATS}, NULL) failed";
     uint32_t nDrive = (uint32_t) (len / sizeof(struct diskstats));
 
-    struct diskstats* stats = malloc(len);
+    FF_AUTO_FREE struct diskstats* stats = malloc(len);
 
     if (sysctl(mib, ARRAY_SIZE(mib), stats, &len, NULL, 0) < 0)
         return "sysctl({HW_DISKSTATS}, stats) failed";
