@@ -1,6 +1,6 @@
 #include "displayserver_linux.h"
-#include "common/io/io.h"
-#include "util/stringUtils.h"
+#include "common/io.h"
+#include "common/stringUtils.h"
 
 #ifdef __FreeBSD__
     #include "common/settings.h"
@@ -95,17 +95,3 @@ void ffConnectDisplayServerImpl(FFDisplayServerResult* ds)
         ffdsDetectWMDE(ds);
     }
 }
-
-FFDisplayType ffdsGetDisplayType(const char* name)
-{
-    if(ffStrStartsWith(name, "eDP-") || ffStrStartsWith(name, "LVDS-"))
-        return FF_DISPLAY_TYPE_BUILTIN;
-    else if(ffStrStartsWith(name, "HDMI-") ||
-            ffStrStartsWith(name, "DP-") ||
-            ffStrStartsWith(name, "DisplayPort-") ||
-            ffStrStartsWith(name, "DVI-") ||
-            ffStrStartsWith(name, "VGA-"))
-        return FF_DISPLAY_TYPE_EXTERNAL;
-
-    return FF_DISPLAY_TYPE_UNKNOWN;
-}
