@@ -1,11 +1,11 @@
 #include "gpu.h"
-#include "common/library.h"
 #include "detection/gpu/gpu_driver_specific.h"
-#include "util/windows/unicode.h"
-#include "util/windows/registry.h"
-#include "util/mallocHelper.h"
-#include "util/debug.h"
-#include "util/windows/nt.h"
+#include "common/library.h"
+#include "common/windows/unicode.h"
+#include "common/windows/registry.h"
+#include "common/mallocHelper.h"
+#include "common/debug.h"
+#include "common/windows/nt.h"
 
 #include <cfgmgr32.h>
 
@@ -47,14 +47,12 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
 
         DEVINST devInst = 0;
 
+        if (CM_Locate_DevNodeW(&devInst, devId, CM_LOCATE_DEVNODE_NORMAL) != CR_SUCCESS)
         {
-            if (CM_Locate_DevNodeW(&devInst, devId, CM_LOCATE_DEVNODE_NORMAL) != CR_SUCCESS)
-            {
-                FF_DEBUG("Failed to get device instance ID or locate device node");
-                continue;
-            }
-            FF_DEBUG("Device instance ID: %lu", devInst);
+            FF_DEBUG("Failed to get device instance ID or locate device node");
+            continue;
         }
+        FF_DEBUG("Device instance ID: %lu", devInst);
 
         FFGPUResult* gpu = (FFGPUResult*)ffListAdd(gpus);
         deviceCount++;
@@ -75,7 +73,10 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
         gpu->frequency = FF_GPU_FREQUENCY_UNSET;
 
         unsigned vendorId = 0, deviceId = 0, subSystemId = 0, revId = 0;
-        if (swscanf(devId, L"PCI\\VEN_%x&DEV_%x&SUBSYS_%x&REV_%x", &vendorId, &deviceId, &subSystemId, &revId) == 4)
+        if (
+            (*devId == 'P' && swscanf(devId, L"PCI\\VEN_%x&DEV_%x&SUBSYS_%x&REV_%x", &vendorId, &deviceId, &subSystemId, &revId) == 4) ||
+            (*devId == 'p' && swscanf(devId, L"pci\\ven_%x&dev_%x&subsys_%x&rev_%x", &vendorId, &deviceId, &subSystemId, &revId) == 4) // Windows 7
+        )
         {
             FF_DEBUG("Parsed PCI IDs - Vendor: 0x%x, Device: 0x%x, SubSystem: 0x%x, Rev: 0x%x", vendorId, deviceId, subSystemId, revId);
             ffStrbufSetStatic(&gpu->vendor, ffGPUGetVendorString(vendorId));
@@ -224,9 +225,9 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
             FF_DEBUG("Failed to open device node registry key");
         }
 
-        if (gpu->vendor.length == 0 || gpu->name.length == 0)
+        if (gpu->vendor.length == 0 || gpu->name.length == 0 || gpu->driver.length == 0 || gpu->dedicated.total == FF_GPU_VMEM_SIZE_UNSET)
         {
-            FF_DEBUG("Trying fallback registry method for vendor/name");
+            FF_DEBUG("Trying fallback registry method for vendor/name etc.");
             bufferLen = sizeof(buffer);
             if (CM_Get_DevNode_Registry_PropertyW(devInst, CM_DRP_DRIVER, NULL, buffer, &bufferLen, 0) == CR_SUCCESS &&
                 bufferLen == (FF_GUID_STRLEN + strlen("\\0000") + 1) * 2)
@@ -329,6 +330,10 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
         if (gpu->type == FF_GPU_TYPE_UNKNOWN && adapterLuid > 0)
         {
             FF_DEBUG("Trying to determine GPU type using D3DKMT APIs");
+            #if !FF_WIN7_COMPAT
+            D3DKMT_OPENADAPTERFROMLUID openAdapterFromLuid = { .AdapterLuid = *(LUID*)&adapterLuid };
+            if (NT_SUCCESS(D3DKMTOpenAdapterFromLuid(&openAdapterFromLuid)))
+            #else
             HMODULE hgdi32 = GetModuleHandleW(L"gdi32.dll");
             if (hgdi32)
             {
@@ -337,6 +342,7 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
                 {
                     D3DKMT_OPENADAPTERFROMLUID openAdapterFromLuid = { .AdapterLuid = *(LUID*)&adapterLuid };
                     if (NT_SUCCESS(ffD3DKMTOpenAdapterFromLuid(&openAdapterFromLuid)))
+            #endif
                     {
                         FF_DEBUG("Successfully opened adapter from LUID");
 
@@ -432,6 +438,7 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
                             FF_DEBUG("Failed to get GPU temperature or temperature is 0");
                         }
                     }
+            #if FF_WIN7_COMPAT
                 }
                 else
                 {
@@ -442,6 +449,7 @@ const char* ffDetectGPUImpl(FF_MAYBE_UNUSED const FFGPUOptions* options, FFlist*
             {
                 FF_DEBUG("Failed to get gdi32.dll module handle");
             }
+            #endif
         }
 
         if (gpu->type == FF_GPU_TYPE_UNKNOWN)
