@@ -1,7 +1,7 @@
 #include "fastfetch.h"
-#include "detection/media/media.h"
 #include "common/processing.h"
-#include "util/apple/cf_helpers.h"
+#include "common/apple/cf_helpers.h"
+#include "detection/media/media.h"
 
 #import <Foundation/Foundation.h>
 #import <CoreFoundation/CoreFoundation.h>
