@@ -1,11 +1,10 @@
 #include "packages.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "common/parsing.h"
-#include "common/processing.h"
 #include "common/properties.h"
 #include "common/settings.h"
+#include "common/stringUtils.h"
 #include "detection/os/os.h"
-#include "util/stringUtils.h"
 
 static uint32_t getNumElements(FFstrbuf* baseDir, const char* dirname, bool isdir)
 {
@@ -124,157 +123,6 @@ static uint32_t countFilesRecursive(FFstrbuf* baseDir, const char* dirname, cons
     return sum;
 }
 
-static bool isValidNixPkg(FFstrbuf* pkg)
-{
-    if (!ffPathExists(pkg->chars, FF_PATHTYPE_DIRECTORY))
-        return false;
-
-    ffStrbufSubstrAfterLastC(pkg, '/');
-    if (
-        ffStrbufStartsWithS(pkg, "nixos-system-nixos-") ||
-        ffStrbufEndsWithS(pkg, "-doc") ||
-        ffStrbufEndsWithS(pkg, "-man") ||
-        ffStrbufEndsWithS(pkg, "-info") ||
-        ffStrbufEndsWithS(pkg, "-dev") ||
-        ffStrbufEndsWithS(pkg, "-bin")
-    ) return false;
-
-    enum { START, DIGIT, DOT, MATCH } state = START;
-
-    for (uint32_t i = 0; i < pkg->length; i++)
-    {
-        char c = pkg->chars[i];
-        switch (state)
-        {
-            case START:
-                if (ffCharIsDigit(c))
-                    state = DIGIT;
-                break;
-            case DIGIT:
-                if (ffCharIsDigit(c))
-                    continue;
-                if (c == '.')
-                    state = DOT;
-                else
-                    state = START;
-                break;
-            case DOT:
-                if (ffCharIsDigit(c))
-                    state = MATCH;
-                else
-                    state = START;
-                break;
-            case MATCH:
-                break;
-        }
-    }
-
-    return state == MATCH;
-}
-
-static bool checkNixCache(FFstrbuf* cacheDir, FFstrbuf* hash, uint32_t* count)
-{
-    if (!ffPathExists(cacheDir->chars, FF_PATHTYPE_FILE))
-        return false;
-
-    FF_STRBUF_AUTO_DESTROY cacheContent = ffStrbufCreate();
-    if (!ffReadFileBuffer(cacheDir->chars, &cacheContent))
-        return false;
-
-    // Format: <hash>\n<count>
-    uint32_t split = ffStrbufFirstIndexC(&cacheContent, '\n');
-    if (split == cacheContent.length)
-        return false;
-
-    ffStrbufSetNS(hash, split, cacheContent.chars);
-    *count = (uint32_t)atoi(cacheContent.chars + split + 1);
-
-    return true;
-}
-
-static bool writeNixCache(FFstrbuf* cacheDir, FFstrbuf* hash, uint32_t count)
-{
-    FF_STRBUF_AUTO_DESTROY cacheContent = ffStrbufCreateCopy(hash);
-    ffStrbufAppendF(&cacheContent, "\n%u", count);
-    return ffWriteFileBuffer(cacheDir->chars, &cacheContent);
-}
-
-static uint32_t getNixPackagesImpl(char* path)
-{
-    //Nix detection is kinda slow, so we only do it if the dir exists
-    if(!ffPathExists(path, FF_PATHTYPE_DIRECTORY))
-        return 0;
-
-    FF_STRBUF_AUTO_DESTROY cacheDir = ffStrbufCreateCopy(&instance.state.platform.cacheDir);
-    ffStrbufEnsureEndsWithC(&cacheDir, '/');
-    ffStrbufAppendS(&cacheDir, "fastfetch/packages/nix");
-    ffStrbufAppendS(&cacheDir, path);
-
-    //Check the hash first to determine if we need to recompute the count
-    FF_STRBUF_AUTO_DESTROY hash = ffStrbufCreateA(64);
-    FF_STRBUF_AUTO_DESTROY cacheHash = ffStrbufCreateA(64);
-    uint32_t count = 0;
-
-    ffProcessAppendStdOut(&hash, (char* const[]) {
-        "nix-store",
-        "--query",
-        "--hash",
-        path,
-        NULL
-    });
-
-    if (checkNixCache(&cacheDir, &cacheHash, &count) && ffStrbufEqual(&hash, &cacheHash))
-        return count;
-
-    //Cache is invalid, recompute the count
-    count = 0;
-
-    //Implementation based on bash script from here:
-    //https://github.com/fastfetch-cli/fastfetch/issues/195#issuecomment-1191748222
-
-    FF_STRBUF_AUTO_DESTROY output = ffStrbufCreateA(1024);
-
-    ffProcessAppendStdOut(&output, (char* const[]) {
-        "nix-store",
-        "--query",
-        "--requisites",
-        path,
-        NULL
-    });
-
-    uint32_t lineLength = 0;
-    for (uint32_t i = 0; i < output.length; i++)
-    {
-        if (output.chars[i] != '\n')
-        {
-            lineLength++;
-            continue;
-        }
-
-        output.chars[i] = '\0';
-        FFstrbuf line = {
-            .allocated = 0,
-            .length = lineLength,
-            .chars = output.chars + i - lineLength
-        };
-        if (isValidNixPkg(&line))
-            count++;
-        lineLength = 0;
-    }
-
-    writeNixCache(&cacheDir, &hash, count);
-    return count;
-}
-
-static uint32_t getNixPackages(FFstrbuf* baseDir, const char* dirname)
-{
-    uint32_t baseDirLength = baseDir->length;
-    ffStrbufAppendS(baseDir, dirname);
-    uint32_t num_elements = getNixPackagesImpl(baseDir->chars);
-    ffStrbufSubstrBefore(baseDir, baseDirLength);
-    return num_elements;
-}
-
 static uint32_t getXBPSImpl(FFstrbuf* baseDir)
 {
     DIR* dir = opendir(baseDir->chars);
@@ -410,8 +258,10 @@ static uint32_t getAMSystem(FFstrbuf* baseDir)
 
 static uint32_t getAMUser(void)
 {
+    if (instance.state.platform.configDirs.length == 0) return 0;
+
     // check if $XDG_CONFIG_HOME/appman/appman-config exists
-    FFstrbuf* baseDir = FF_LIST_GET(FFstrbuf, instance.state.platform.configDirs, 0);
+    FFstrbuf* baseDir = FF_LIST_FIRST(FFstrbuf, instance.state.platform.configDirs);
     uint32_t baseLen = baseDir->length;
     ffStrbufAppendS(baseDir, "appman/appman-config");
     FF_STRBUF_AUTO_DESTROY packagesPath = ffStrbufCreate();
@@ -570,10 +420,11 @@ static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts,
     if (!(options->disabled & FF_PACKAGES_FLAG_EMERGE_BIT)) packageCounts->emerge += countFilesRecursive(baseDir, "/var/db/pkg", "SIZE");
     if (!(options->disabled & FF_PACKAGES_FLAG_EOPKG_BIT)) packageCounts->eopkg += getNumElements(baseDir, "/var/lib/eopkg/package", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_FLATPAK_BIT)) packageCounts->flatpakSystem += getFlatpakPackages(baseDir, "/var/lib");
+    if (!(options->disabled & FF_PACKAGES_FLAG_KISS_BIT)) packageCounts->kiss += getNumElements(baseDir, "/var/db/kiss/installed", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_NIX_BIT))
     {
-        packageCounts->nixDefault += getNixPackages(baseDir, "/nix/var/nix/profiles/default");
-        packageCounts->nixSystem += getNixPackages(baseDir, "/run/current-system");
+        packageCounts->nixDefault += ffPackagesGetNix(baseDir, "/nix/var/nix/profiles/default");
+        packageCounts->nixSystem += ffPackagesGetNix(baseDir, "/run/current-system");
     }
     if (!(options->disabled & FF_PACKAGES_FLAG_PACMAN_BIT)) packageCounts->pacman += getNumElements(baseDir, "/var/lib/pacman/local", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_LPKGBUILD_BIT)) packageCounts->lpkgbuild += getNumElements(baseDir, "/opt/Loc-OS-LPKG/lpkgbuild/remove", false);
@@ -598,7 +449,7 @@ static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts,
     {
       packageCounts->guixSystem += getGuixPackages(baseDir, "/run/current-system/profile");
     }
-    if (!(options->disabled & FF_PACKAGES_FLAG_LINGLONG_BIT)) packageCounts->linglong += getNumElements(baseDir, "/var/lib/linglong/repo/refs/heads/main", true);
+    if (!(options->disabled & FF_PACKAGES_FLAG_LINGLONG_BIT)) packageCounts->linglong += getNumElements(baseDir, "/var/lib/linglong/layers", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_PACSTALL_BIT)) packageCounts->pacstall += getNumElements(baseDir, "/var/lib/pacstall/metadata", false);
     if (!(options->disabled & FF_PACKAGES_FLAG_PISI_BIT)) packageCounts->pisi += getNumElements(baseDir, "/var/lib/pisi/package", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_PKGSRC_BIT)) packageCounts->pkgsrc += getNumElements(baseDir, "/usr/pkg/pkgdb", DT_DIR);
@@ -669,11 +520,10 @@ void ffDetectPackagesImpl(FFPackagesResult* result, FFPackagesOptions* options)
     #endif
 
     ffStrbufSet(&baseDir, &instance.state.platform.homeDir);
-
     if (!(options->disabled & FF_PACKAGES_FLAG_NIX_BIT))
     {
         // Count packages from $HOME/.nix-profile
-        result->nixUser += getNixPackages(&baseDir, ".nix-profile");
+        result->nixUser += ffPackagesGetNix(&baseDir, ".nix-profile");
 
         // Check in $XDG_STATE_HOME/nix/profile
         FF_STRBUF_AUTO_DESTROY stateHome = ffStrbufCreate();
@@ -688,11 +538,11 @@ void ffDetectPackagesImpl(FFPackagesResult* result, FFPackagesOptions* options)
             ffStrbufSet(&stateHome, &instance.state.platform.homeDir);
             ffStrbufAppendS(&stateHome, ".local/state/");
         }
-        result->nixUser += getNixPackages(&stateHome, "nix/profile");
+        result->nixUser += ffPackagesGetNix(&stateHome, "nix/profile");
 
         // Check in /etc/profiles/per-user/$USER
         FF_STRBUF_AUTO_DESTROY userPkgsDir = ffStrbufCreateStatic("/etc/profiles/per-user/");
-        result->nixUser += getNixPackages(&userPkgsDir, instance.state.platform.userName.chars);
+        result->nixUser += ffPackagesGetNix(&userPkgsDir, instance.state.platform.userName.chars);
     }
 
     if (!(options->disabled & FF_PACKAGES_FLAG_GUIX_BIT))
