@@ -1,14 +1,15 @@
+#include "common/font.h"
 #include "terminalfont.h"
 #include "common/settings.h"
 #include "common/properties.h"
 #include "common/parsing.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "common/processing.h"
+#include "common/mallocHelper.h"
+#include "common/stringUtils.h"
+#include "common/binary.h"
 #include "detection/terminalshell/terminalshell.h"
 #include "detection/displayserver/displayserver.h"
-#include "util/mallocHelper.h"
-#include "util/stringUtils.h"
-#include "util/binary.h"
 
 static const char* getSystemMonospaceFont(void)
 {
@@ -286,6 +287,14 @@ static void detectXterm(FFTerminalFontResult* terminalFont)
         {"xterm*faceSize:", &fontSize},
     });
 
+    if (fontName.length == 0)
+    {
+        ffParsePropFileHomeValues(".Xresources", 2, (FFpropquery[]) {
+            {"xterm.vt100.faceName:", &fontName},
+            {"xterm.vt100.faceSize:", &fontSize},
+        });
+    }
+
     if (fontName.length == 0)
         ffStrbufAppendS(&fontName, "fixed");
     if (fontSize.length == 0)
@@ -418,6 +427,67 @@ static void detectWestonTerminal(FFTerminalFontResult* terminalFont)
     ffFontInitValues(&terminalFont->font, font.chars, size.chars);
 }
 
+static void detectUrxvt(FFTerminalFontResult* terminalFont)
+{
+    FF_STRBUF_AUTO_DESTROY buffer = ffStrbufCreate();
+
+    if (!(ffParsePropFileHomeValues(".Xresources", 1, (FFpropquery[]) {
+        {"URxvt.font:", &buffer},
+    }) || ffParsePropFileHomeValues(".Xdefaults", 1, (FFpropquery[]) {
+        {"URxvt.font:", &buffer},
+    })))
+    {
+        ffStrbufAppendS(&terminalFont->error, "Could not find URxvt.font in .Xresources or .Xdefaults");
+        return;
+    }
+
+    uint32_t index = 0;
+
+    char* line = NULL;
+    size_t len = 0;
+    while (ffStrbufGetdelim(&line, &len, ',', &buffer))
+    {
+        FFfont* font = index == 0 ? &terminalFont->font : &terminalFont->fallback;
+        if (line[0] == '-')
+            ffFontInitXlfd(font, line);
+        else if (ffStrStartsWith(line, "xft:"))
+            ffFontInitXft(font, line + 4);
+        else
+        {
+            ffStrbufAppendF(&terminalFont->error, "Unknown URxvt font format: %s", line);
+            continue;
+        }
+        index++;
+        if (index > 1) break;
+    }
+}
+
+static bool detectCosmicTerm(FFTerminalFontResult* terminalFont)
+{
+    FF_STRBUF_AUTO_DESTROY fontName = ffStrbufCreate();
+    FF_STRBUF_AUTO_DESTROY fontSize = ffStrbufCreate();
+
+    FF_STRBUF_AUTO_DESTROY path = ffStrbufCreateCopy(&instance.state.platform.homeDir);
+    ffStrbufAppendS(&path, ".config/cosmic/com.system76.CosmicTerm/v1/");
+    uint32_t baseLen = path.length;
+
+    ffStrbufAppendS(&path, "font_name");
+    ffReadFileBuffer(path.chars, &fontName);
+    ffStrbufTrim(&path, '"');
+    ffStrbufSubstrBefore(&path, baseLen);
+    if (fontName.length == 0) ffStrbufSetStatic(&fontName, "Noto Sans Mono");
+
+    ffStrbufAppendS(&path, "font_size");
+    if (ffReadFileBuffer(path.chars, &fontSize))
+        ffStrbufAppendS(&fontSize, "px");
+    ffStrbufSubstrBefore(&path, baseLen);
+    if (fontSize.length == 0) ffStrbufSetStatic(&fontSize, "14px");
+
+    ffFontInitValues(&terminalFont->font, fontName.chars, fontSize.chars);
+
+    return true;
+}
+
 #ifdef __HAIKU__
 static void detectHaikuTerminal(FFTerminalFontResult* terminalFont)
 {
@@ -477,12 +547,18 @@ ffDetectTerminalFontPlatform
         detectTerminator(terminalFont);
     else if(ffStrbufStartsWithIgnCaseS(&terminal->processName, "sakura"))
         detectFromConfigFile("sakura/sakura.conf", "font=", terminalFont);
+    else if(ffStrbufStartsWithIgnCaseS(&terminal->processName, "cosmic-term"))
+        detectCosmicTerm(terminalFont);
     #ifdef __HAIKU__
     else if(ffStrbufStartsWithIgnCaseS(&terminal->processName, "Terminal"))
         detectHaikuTerminal(terminalFont);
     #endif
     else if(ffStrbufStartsWithIgnCaseS(&terminal->processName, "termite"))
         detectFromConfigFile("termite/config", "font =", terminalFont);
+    else if(ffStrbufIgnCaseEqualS(&terminal->processName, "rxvt")
+        || ffStrbufIgnCaseEqualS(&terminal->processName, "urxvt")
+        || ffStrbufIgnCaseEqualS(&terminal->processName, "urxvtd"))
+        detectUrxvt(terminalFont);
     else
         return false;
     return true;
