@@ -1,11 +1,13 @@
 #include "fastfetch.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "common/processing.h"
 #include "common/properties.h"
-#include "util/stringUtils.h"
-#include "util/binary.h"
+#include "common/path.h"
+#include "common/stringUtils.h"
+#include "common/binary.h"
 
 #include <ctype.h>
+#include <stdint.h>
 #ifdef __FreeBSD__
     #include <paths.h>
     #ifndef _PATH_LOCALBASE
@@ -17,7 +19,7 @@
     #define _PATH_LOCALBASE "/usr/pkg"
 #elif _WIN32
 
-#include "util/windows/version.h"
+#include "common/windows/version.h"
 #include <windows.h>
 
 static bool getFileVersion(const FFstrbuf* exePath, const wchar_t* stringName, FFstrbuf* version)
@@ -31,7 +33,7 @@ static bool getFileVersion(const FFstrbuf* exePath, const wchar_t* stringName, F
 }
 
 #elif __HAIKU__
-    #include "util/haiku/version.h"
+    #include "common/haiku/version.h"
 #endif
 
 static bool getExeVersionRaw(FFstrbuf* exe, FFstrbuf* version)
@@ -63,12 +65,10 @@ static bool extractBashVersion(const char* line, FF_MAYBE_UNUSED uint32_t len, v
     return false;
 }
 
-static bool getShellVersionBash(FFstrbuf* exe, FFstrbuf* exePath, FFstrbuf* version)
+static bool getShellVersionBash(FFstrbuf* exe, FFstrbuf* version)
 {
-    const char* path = exePath->chars;
-    if (*path == '\0')
-        path = exe->chars;
-    ffBinaryExtractStrings(path, extractBashVersion, version, (uint32_t) strlen("@(#)Bash version 0.0.0(0) release GNU"));
+    ffBinaryExtractStrings(exe->chars, extractBashVersion, version, (uint32_t) strlen("@(#)Bash version 0.0.0(0) release GNU"));
+    if (version->length > 0) return true;
 
     if(!getExeVersionRaw(exe, version))
         return false;
@@ -84,8 +84,11 @@ static bool getShellVersionFish(FFstrbuf* exe, FFstrbuf* version)
     if(!getExeVersionRaw(exe, version))
         return false;
 
-    //fish, version 3.6.0
-    ffStrbufSubstrAfterLastC(version, ' ');
+    //fish, version 4.0.2-1 (Built by MSYS2 project) // version can be localized if LC_ALL is set
+    if (version->length < strlen("fish, v") || !ffStrbufStartsWithS(version, "fish")) return false;
+    uint32_t index = ffStrbufNextIndexC(version, strlen("fish, "), ' ');
+    ffStrbufSubstrAfter(version, index);
+    ffStrbufSubstrBeforeFirstC(version, ' ');
     return true;
 }
 
@@ -117,35 +120,39 @@ static bool getShellVersionPwsh(FFstrbuf* exe, FFstrbuf* version)
 
 static bool getShellVersionKsh(FFstrbuf* exe, FFstrbuf* version)
 {
-#if __OpenBSD__ || __NetBSD__
+    if(ffProcessAppendStdErr(version, (char* const[]) {
+        exe->chars,
+        "--version",
+        NULL
+    }) == NULL && ffStrbufSubstrAfterFirstS(version, " (AT&T Research) "))
+    {
+        //  version         sh (AT&T Research) 93u+ 2012-08-01
+        ffStrbufSubstrBeforeFirstC(version, ' ');
+        return true;
+    }
+
+    ffStrbufClear(version);
     if(ffProcessAppendStdOut(version, (char* const[]) {
         exe->chars,
         "-c",
         "echo $KSH_VERSION",
         NULL
-    }) != NULL)
-        return false;
+    }) == NULL && ffStrbufSubstrAfterFirstS(version, " KSH "))
+    {
+        // OKSH: @(#)PD KSH v5.2.14 99/07/13.2
+        // MKSH: @(#)MIRBSD KSH R59 2025/04/26 +Debian
+        // $OKSH_VERSION doesn't exist on OpenBSD
+        ffStrbufSubstrBeforeFirstC(version, ' ');
+        ffStrbufTrimLeft(version, 'v');
+        return true;
+    }
 
-    // @(#)PD KSH v5.2.14 99/07/13.2
-    ffStrbufSubstrAfterFirstC(version, 'v');
-    ffStrbufSubstrBeforeFirstC(version, ' ');
-#else
-    if(ffProcessAppendStdErr(version, (char* const[]) {
-        exe->chars,
-        "--version",
-        NULL
-    }) != NULL)
-        return false;
-
-    //  version         sh (AT&T Research) 93u+ 2012-08-01
-    ffStrbufSubstrAfterLastC(version, ')');
-    ffStrbufTrim(version, ' ');
-#endif
-    return true;
+    return false;
 }
 
 static bool getShellVersionOksh(FFstrbuf* exe, FFstrbuf* version)
 {
+    // Homebrew version
     if(ffProcessAppendStdOut(version, (char* const[]) {
         exe->chars,
         "-c",
@@ -197,13 +204,14 @@ static bool getShellVersionAsh(FFstrbuf* exe, FFstrbuf* version)
     return true;
 }
 
-static bool getShellVersionXonsh(FFstrbuf* exe, FFstrbuf* version)
+static bool getShellVersionXonsh(FF_MAYBE_UNUSED FFstrbuf* exe, FFstrbuf* version)
 {
     ffStrbufSetS(version, getenv("XONSH_VERSION"));
     if (version->length) return true;
 
+    // exe is python here
     if(ffProcessAppendStdErr(version, (char* const[]) {
-        exe->chars,
+        "xonsh",
         "--version",
         NULL
     }) != NULL)
@@ -225,13 +233,9 @@ static bool extractZshVersion(const char* line, FF_MAYBE_UNUSED uint32_t len, vo
     return false;
 }
 
-static bool getShellVersionZsh(FFstrbuf* exe, FFstrbuf* exePath, FFstrbuf* version)
+static bool getShellVersionZsh(FFstrbuf* exe, FFstrbuf* version)
 {
-    const char* path = exePath->chars;
-    if (*path == '\0')
-        path = exe->chars;
-
-    ffBinaryExtractStrings(path, extractZshVersion, version, (uint32_t) strlen("zsh-0.0-0"));
+    ffBinaryExtractStrings(exe->chars, extractZshVersion, version, (uint32_t) strlen("zsh-0.0-0"));
     if (version->length) return true;
 
     return getExeVersionGeneral(exe, version); //zsh 5.9 (arm-apple-darwin21.3.0)
@@ -258,7 +262,7 @@ static bool getShellVersionWinPowerShell(FFstrbuf* exe, FFstrbuf* version)
 }
 #endif
 
-bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* exePath, FFstrbuf* version)
+bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* version)
 {
     if (!instance.config.general.detectVersion) return false;
 
@@ -266,9 +270,9 @@ bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* exePath,
         return false;
 
     if(ffStrEqualsIgnCase(exeName, "bash"))
-        return getShellVersionBash(exe, exePath, version);
+        return getShellVersionBash(exe, version);
     if(ffStrEqualsIgnCase(exeName, "zsh"))
-        return getShellVersionZsh(exe, exePath, version);
+        return getShellVersionZsh(exe, version);
     if(ffStrEqualsIgnCase(exeName, "fish"))
         return getShellVersionFish(exe, version);
     if(ffStrEqualsIgnCase(exeName, "pwsh"))
@@ -277,7 +281,7 @@ bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* exePath,
         return getExeVersionGeneral(exe, version); //tcsh 6.24.07 (Astron) 2022-12-21 (aarch64-apple-darwin) options wide,nls,dl,al,kan,sm,rh,color,filec
     if(ffStrEqualsIgnCase(exeName, "nu"))
         return getShellVersionNushell(exe, version);
-    if(ffStrEqualsIgnCase(exeName, "ksh"))
+    if(ffStrEqualsIgnCase(exeName, "ksh") || ffStrEqualsIgnCase(exeName, "mksh"))
         return getShellVersionKsh(exe, version);
     if(ffStrEqualsIgnCase(exeName, "oksh"))
         return getShellVersionOksh(exe, version);
@@ -289,6 +293,8 @@ bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* exePath,
         return getShellVersionAsh(exe, version);
     if(ffStrEqualsIgnCase(exeName, "xonsh"))
         return getShellVersionXonsh(exe, version);
+    if(ffStrEqualsIgnCase(exeName, "brush"))
+        return getExeVersionGeneral(exe, version); // brush 0.2.23 (git:2835487)
 
     #ifdef _WIN32
     if(ffStrEqualsIgnCase(exeName, "powershell") || ffStrEqualsIgnCase(exeName, "powershell_ise"))
@@ -318,7 +324,7 @@ static bool extractGeneralVersion(const char *str, FF_MAYBE_UNUSED uint32_t len,
 
 FF_MAYBE_UNUSED static bool getTerminalVersionGnome(FFstrbuf* exe, FFstrbuf* version)
 {
-    if (exe->chars[0] == '/')
+    if (ffIsAbsolutePath(exe->chars))
     {
         ffBinaryExtractStrings(exe->chars, extractGeneralVersion, version, (uint32_t) strlen("0.0.0"));
         if (version->length) return true;
@@ -338,7 +344,7 @@ FF_MAYBE_UNUSED static bool getTerminalVersionGnome(FFstrbuf* exe, FFstrbuf* ver
 
 FF_MAYBE_UNUSED static bool getTerminalVersionXfce4Terminal(FFstrbuf* exe, FFstrbuf* version)
 {
-    if (exe->chars[0] == '/')
+    if (ffIsAbsolutePath(exe->chars))
     {
         ffBinaryExtractStrings(exe->chars, extractGeneralVersion, version, (uint32_t) strlen("0.0.0"));
         if (version->length) return true;
@@ -575,13 +581,51 @@ static bool getTerminalVersionZed(FFstrbuf* exe, FFstrbuf* version)
     return true;
 }
 
+static bool extractSshdVersion(const char *str, FF_MAYBE_UNUSED uint32_t len, void *userdata)
+{
+    if (!ffStrStartsWith(str, "OpenSSH_") || !ffCharIsDigit(str[strlen("OpenSSH_")])) return true;
+    str += strlen("OpenSSH_");
+    int count = 0;
+    sscanf(str, "%*d.%*dp%*d%n", &count);
+    if (count == 0) return true;
+    ffStrbufSetS((FFstrbuf*) userdata, str);
+    return false;
+}
+
+static bool getTerminalVersionSshd(FFstrbuf* exe, FFstrbuf* version)
+{
+    FF_STRBUF_AUTO_DESTROY exePath = ffStrbufCreate();
+    if (ffIsAbsolutePath(exe->chars))
+        ffStrbufSet(&exePath, exe);
+    else if (ffFindExecutableInPath("sshd", &exePath) != NULL)
+        return false;
+
+    ffBinaryExtractStrings(exePath.chars, extractSshdVersion, version, (uint32_t) strlen("OpenSSH0.0"));
+    if (version->length) return true;
+
+    if(ffProcessAppendStdOut(version, (char* const[]) {
+        exePath.chars,
+        "-V",
+        NULL
+    }) != NULL)
+        return false;
+
+    if (ffStrbufStartsWithS(version, "unknown ")) // `unknown option -- V` (ancient OpenSSH version)
+        ffStrbufSubstrAfterFirstC(version, '\n');
+
+    // OpenSSH_10.0p2 Ubuntu-5ubuntu5, OpenSSL 3.5.3 16 Sep 2025
+    ffStrbufSubstrAfterFirstC(version, '_');
+    ffStrbufSubstrBeforeFirstC(version, ',');
+    return true;
+}
+
 #ifndef _WIN32
 static bool getTerminalVersionKitty(FFstrbuf* exe, FFstrbuf* version)
 {
-    #if defined(__linux__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
+    #if defined(__linux__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__GNU__)
     char buffer[1024] = {};
     if (
-        #ifdef __linux__
+        #if __linux__ || __GNU__
         ffReadFileData(FASTFETCH_TARGET_DIR_USR "/lib64/kitty/kitty/constants.py", ARRAY_SIZE(buffer) - 1, buffer) ||
         ffReadFileData(FASTFETCH_TARGET_DIR_USR "/lib/kitty/kitty/constants.py", ARRAY_SIZE(buffer) - 1, buffer)
         #else
@@ -674,7 +718,7 @@ FF_MAYBE_UNUSED static bool getTerminalVersionPtyxis(FF_MAYBE_UNUSED FFstrbuf* e
 
 FF_MAYBE_UNUSED static bool getTerminalVersionTilix(FFstrbuf* exe, FFstrbuf* version)
 {
-    if (exe->chars[0] == '/')
+    if (ffIsAbsolutePath(exe->chars))
     {
         ffBinaryExtractStrings(exe->chars, extractGeneralVersion, version, (uint32_t) strlen("0.0.0"));
         if (version->length) return true;
@@ -766,7 +810,7 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
 
     #endif
 
-    #if defined(__linux__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__sun) || defined(__NetBSD__) || defined(__HAIKU__)
+    #if defined(__linux__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__sun) || defined(__NetBSD__) || defined(__HAIKU__) || defined(__GNU__)
 
     if(ffStrbufStartsWithIgnCaseS(processName, "gnome-terminal"))
         return getTerminalVersionGnome(exe, version);
@@ -832,6 +876,9 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
     if(ffStrbufIgnCaseEqualS(processName, "termite"))
         return getTerminalVersionTermite(exe, version);
 
+    if(ffStrbufIgnCaseEqualS(processName, "cosmic-term"))
+        return getTerminalVersionTmux(exe, version);
+
     #endif
 
     #ifdef _WIN32
@@ -918,6 +965,9 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
     if(ffStrbufStartsWithIgnCaseS(processName, "tmux"))
         return getTerminalVersionTmux(exe, version);
 
+    if(ffStrbufIgnCaseEqualS(processName, "sshd") || ffStrbufStartsWithIgnCaseS(processName, "sshd-"))
+        return getTerminalVersionSshd(exe, version);
+
     #ifdef _WIN32
 
     return getFileVersion(exe, NULL, version);
