@@ -1,10 +1,10 @@
 #include "wifi.h"
 #include "common/dbus.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "common/processing.h"
 #include "common/properties.h"
-#include "util/stringUtils.h"
-#include "util/debug.h"
+#include "common/stringUtils.h"
+#include "common/debug.h"
 
 #include <net/if.h>
 
