@@ -1,8 +1,8 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/cursor/cursor.h"
 #include "modules/cursor/cursor.h"
-#include "util/stringUtils.h"
 
 bool ffPrintCursor(FFCursorOptions* options)
 {
