@@ -4,7 +4,7 @@
 
 #define FF_INITSYSTEM_MODULE_NAME "InitSystem"
 
-void ffPrintInitSystem(FFInitSystemOptions* options);
+bool ffPrintInitSystem(FFInitSystemOptions* options);
 void ffInitInitSystemOptions(FFInitSystemOptions* options);
 void ffDestroyInitSystemOptions(FFInitSystemOptions* options);
 
