@@ -1,8 +1,8 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/displayserver/displayserver.h"
 #include "modules/monitor/monitor.h"
-#include "util/stringUtils.h"
 
 #include <math.h>
 
