@@ -1,9 +1,9 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
 #include "common/option.h"
+#include "common/stringUtils.h"
 #include "detection/os/os.h"
 #include "modules/os/os.h"
-#include "util/stringUtils.h"
 
 #include <ctype.h>
 
