@@ -1,10 +1,10 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/packages/packages.h"
 #include "modules/packages/packages.h"
-#include "util/stringUtils.h"
 
-void ffPrintPackages(FFPackagesOptions* options)
+bool ffPrintPackages(FFPackagesOptions* options)
 {
     FFPackagesResult counts = {};
     ffStrbufInit(&counts.pacmanBranch);
@@ -14,7 +14,7 @@ void ffPrintPackages(FFPackagesOptions* options)
     if(error)
     {
         ffPrintError(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
-        return;
+        return false;
     }
 
     uint32_t nixAll = counts.nixDefault + counts.nixSystem + counts.nixUser;
@@ -76,6 +76,7 @@ void ffPrintPackages(FFPackagesOptions* options)
         FF_PRINT_PACKAGE(apk)
         FF_PRINT_PACKAGE(pkg)
         FF_PRINT_PACKAGE(pkgsrc)
+        FF_PRINT_PACKAGE(kiss)
         if (options->combined)
         {
             FF_PRINT_PACKAGE_ALL(hpkg)
@@ -194,6 +195,7 @@ void ffPrintPackages(FFPackagesOptions* options)
             FF_FORMAT_ARG(counts.hpkgUser, "hpkg-user"),
             FF_FORMAT_ARG(counts.pisi, "pisi"),
             FF_FORMAT_ARG(counts.soar, "soar"),
+            FF_FORMAT_ARG(counts.kiss, "kiss"),
             FF_FORMAT_ARG(nixAll, "nix-all"),
             FF_FORMAT_ARG(flatpakAll, "flatpak-all"),
             FF_FORMAT_ARG(brewAll, "brew-all"),
@@ -203,137 +205,24 @@ void ffPrintPackages(FFPackagesOptions* options)
     }
 
     ffStrbufDestroy(&counts.pacmanBranch);
-}
 
-bool ffParsePackagesCommandOptions(FFPackagesOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_PACKAGES_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    if (ffStrEqualsIgnCase(subKey, "disabled"))
-    {
-        options->disabled = FF_PACKAGES_FLAG_NONE;
-        FF_STRBUF_AUTO_DESTROY buffer = ffStrbufCreate();
-        ffOptionParseString(key, value, &buffer);
-
-        char *start = buffer.chars, *end = strchr(start, ':');
-        while (true)
-        {
-            if (end)
-                *end = '\0';
-
-            #define FF_TEST_PACKAGE_NAME(name) else if (ffStrEqualsIgnCase(start, #name)) { options->disabled |= FF_PACKAGES_FLAG_ ## name ## _BIT; }
-            switch (toupper(start[0]))
-            {
-                case 'A': if (false);
-                    FF_TEST_PACKAGE_NAME(APK)
-                    FF_TEST_PACKAGE_NAME(AM)
-                    break;
-                case 'B': if (false);
-                    FF_TEST_PACKAGE_NAME(BREW)
-                    break;
-                case 'C': if (false);
-                    FF_TEST_PACKAGE_NAME(CHOCO)
-                    break;
-                case 'D': if (false);
-                    FF_TEST_PACKAGE_NAME(DPKG)
-                    break;
-                case 'E': if (false);
-                    FF_TEST_PACKAGE_NAME(EMERGE)
-                    FF_TEST_PACKAGE_NAME(EOPKG)
-                    break;
-                case 'F': if (false);
-                    FF_TEST_PACKAGE_NAME(FLATPAK)
-                    break;
-                case 'G': if (false);
-                    FF_TEST_PACKAGE_NAME(GUIX)
-                    break;
-                case 'H': if (false);
-                    FF_TEST_PACKAGE_NAME(HPKG)
-                    break;
-                case 'L': if (false);
-                    FF_TEST_PACKAGE_NAME(LPKG)
-                    FF_TEST_PACKAGE_NAME(LPKGBUILD)
-                    FF_TEST_PACKAGE_NAME(LINGLONG)
-                    break;
-                case 'M': if (false);
-                    FF_TEST_PACKAGE_NAME(MACPORTS)
-                    FF_TEST_PACKAGE_NAME(MPORT)
-                    break;
-                case 'N': if (false);
-                    FF_TEST_PACKAGE_NAME(NIX)
-                    break;
-                case 'O': if (false);
-                    FF_TEST_PACKAGE_NAME(OPKG)
-                    break;
-                case 'P': if (false);
-                    FF_TEST_PACKAGE_NAME(PACMAN)
-                    FF_TEST_PACKAGE_NAME(PACSTALL)
-                    FF_TEST_PACKAGE_NAME(PALUDIS)
-                    FF_TEST_PACKAGE_NAME(PISI)
-                    FF_TEST_PACKAGE_NAME(PKG)
-                    FF_TEST_PACKAGE_NAME(PKGTOOL)
-                    FF_TEST_PACKAGE_NAME(PKGSRC)
-                    break;
-                case 'R': if (false);
-                    FF_TEST_PACKAGE_NAME(RPM)
-                    break;
-                case 'S': if (false);
-                    FF_TEST_PACKAGE_NAME(SCOOP)
-                    FF_TEST_PACKAGE_NAME(SNAP)
-                    FF_TEST_PACKAGE_NAME(SOAR)
-                    FF_TEST_PACKAGE_NAME(SORCERY)
-                    break;
-                case 'W': if (false);
-                    FF_TEST_PACKAGE_NAME(WINGET)
-                    break;
-                case 'X': if (false);
-                    FF_TEST_PACKAGE_NAME(XBPS)
-                    break;
-            }
-            #undef FF_TEST_PACKAGE_NAME
-
-            if (end)
-            {
-                start = end + 1;
-                end = strchr(start, ':');
-            }
-            else
-                break;
-        }
-
-        return true;
-    }
-
-    if (ffStrEqualsIgnCase(subKey, "combined"))
-    {
-        options->combined = ffOptionParseBoolean(value);
-        return true;
-    }
-
-    return false;
+    return true;
 }
 
 void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if (ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        if (ffStrEqualsIgnCase(key, "disabled"))
+        if (unsafe_yyjson_equals_str(key, "disabled"))
         {
             if (!yyjson_is_null(val) && !yyjson_is_arr(val))
             {
-                ffPrintError(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid JSON value for %s", key);
+                ffPrintError(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid JSON value for %s", unsafe_yyjson_get_str(key));
                 continue;
             }
 
@@ -345,7 +234,12 @@ void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
                 size_t flagIdx, flagMax;
                 yyjson_arr_foreach(val, flagIdx, flagMax, flagObj)
                 {
-                    const char* flag = yyjson_get_str(flagObj);
+                    if (!yyjson_is_str(flagObj))
+                    {
+                        ffPrintError(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid JSON value for %s", unsafe_yyjson_get_str(key));
+                        continue;
+                    }
+                    const char* flag = unsafe_yyjson_get_str(flagObj);
 
                     #define FF_TEST_PACKAGE_NAME(name) else if (ffStrEqualsIgnCase(flag, #name)) { options->disabled |= FF_PACKAGES_FLAG_ ## name ## _BIT; }
                     switch (toupper(flag[0]))
@@ -376,6 +270,9 @@ void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
                         case 'H': if (false);
                             FF_TEST_PACKAGE_NAME(HPKG)
                             break;
+                        case 'K': if (false);
+                            FF_TEST_PACKAGE_NAME(KISS)
+                            break;
                         case 'L': if (false);
                             FF_TEST_PACKAGE_NAME(LPKG)
                             FF_TEST_PACKAGE_NAME(LPKGBUILD)
@@ -422,67 +319,66 @@ void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
             }
         }
 
-        if (ffStrEqualsIgnCase(key, "combined"))
+        if (unsafe_yyjson_equals_str(key, "combined"))
         {
             options->combined = yyjson_get_bool(val);
             continue;
         }
 
-        ffPrintError(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGeneratePackagesJsonConfig(FFPackagesOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyPackagesOptions))) FFPackagesOptions defaultOptions;
-    ffInitPackagesOptions(&defaultOptions);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
-
-    if (options->disabled != defaultOptions.disabled)
-    {
-        yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "disabled");
-        #define FF_TEST_PACKAGE_NAME(name) else if ((options->disabled & FF_PACKAGES_FLAG_ ## name ## _BIT) != (defaultOptions.disabled & FF_PACKAGES_FLAG_ ## name ## _BIT)) { yyjson_mut_arr_add_str(doc, arr, #name); }
-        if (false);
-        FF_TEST_PACKAGE_NAME(AM)
-        FF_TEST_PACKAGE_NAME(APK)
-        FF_TEST_PACKAGE_NAME(BREW)
-        FF_TEST_PACKAGE_NAME(CHOCO)
-        FF_TEST_PACKAGE_NAME(DPKG)
-        FF_TEST_PACKAGE_NAME(EMERGE)
-        FF_TEST_PACKAGE_NAME(EOPKG)
-        FF_TEST_PACKAGE_NAME(FLATPAK)
-        FF_TEST_PACKAGE_NAME(GUIX)
-        FF_TEST_PACKAGE_NAME(HPKG)
-        FF_TEST_PACKAGE_NAME(LINGLONG)
-        FF_TEST_PACKAGE_NAME(LPKG)
-        FF_TEST_PACKAGE_NAME(LPKGBUILD)
-        FF_TEST_PACKAGE_NAME(MACPORTS)
-        FF_TEST_PACKAGE_NAME(MPORT)
-        FF_TEST_PACKAGE_NAME(NIX)
-        FF_TEST_PACKAGE_NAME(OPKG)
-        FF_TEST_PACKAGE_NAME(PACMAN)
-        FF_TEST_PACKAGE_NAME(PACSTALL)
-        FF_TEST_PACKAGE_NAME(PALUDIS)
-        FF_TEST_PACKAGE_NAME(PISI)
-        FF_TEST_PACKAGE_NAME(PKG)
-        FF_TEST_PACKAGE_NAME(PKGTOOL)
-        FF_TEST_PACKAGE_NAME(PKGSRC)
-        FF_TEST_PACKAGE_NAME(RPM)
-        FF_TEST_PACKAGE_NAME(SCOOP)
-        FF_TEST_PACKAGE_NAME(SNAP)
-        FF_TEST_PACKAGE_NAME(SOAR)
-        FF_TEST_PACKAGE_NAME(SORCERY)
-        FF_TEST_PACKAGE_NAME(WINGET)
-        FF_TEST_PACKAGE_NAME(XBPS)
-        #undef FF_TEST_PACKAGE_NAME
+    FF_STRBUF_AUTO_DESTROY buf = ffStrbufCreate();
+    yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "disabled");
+    #define FF_TEST_PACKAGE_NAME(name) else if ((options->disabled & FF_PACKAGES_FLAG_ ## name ## _BIT)) { \
+        ffStrbufSetS(&buf, #name); \
+        ffStrbufLowerCase(&buf); \
+        yyjson_mut_arr_add_strbuf(doc, arr, &buf); \
     }
+    if (false);
+    FF_TEST_PACKAGE_NAME(AM)
+    FF_TEST_PACKAGE_NAME(APK)
+    FF_TEST_PACKAGE_NAME(BREW)
+    FF_TEST_PACKAGE_NAME(CHOCO)
+    FF_TEST_PACKAGE_NAME(DPKG)
+    FF_TEST_PACKAGE_NAME(EMERGE)
+    FF_TEST_PACKAGE_NAME(EOPKG)
+    FF_TEST_PACKAGE_NAME(FLATPAK)
+    FF_TEST_PACKAGE_NAME(GUIX)
+    FF_TEST_PACKAGE_NAME(HPKG)
+    FF_TEST_PACKAGE_NAME(KISS)
+    FF_TEST_PACKAGE_NAME(LINGLONG)
+    FF_TEST_PACKAGE_NAME(LPKG)
+    FF_TEST_PACKAGE_NAME(LPKGBUILD)
+    FF_TEST_PACKAGE_NAME(MACPORTS)
+    FF_TEST_PACKAGE_NAME(MPORT)
+    FF_TEST_PACKAGE_NAME(NIX)
+    FF_TEST_PACKAGE_NAME(OPKG)
+    FF_TEST_PACKAGE_NAME(PACMAN)
+    FF_TEST_PACKAGE_NAME(PACSTALL)
+    FF_TEST_PACKAGE_NAME(PALUDIS)
+    FF_TEST_PACKAGE_NAME(PISI)
+    FF_TEST_PACKAGE_NAME(PKG)
+    FF_TEST_PACKAGE_NAME(PKGTOOL)
+    FF_TEST_PACKAGE_NAME(PKGSRC)
+    FF_TEST_PACKAGE_NAME(RPM)
+    FF_TEST_PACKAGE_NAME(SCOOP)
+    FF_TEST_PACKAGE_NAME(SNAP)
+    FF_TEST_PACKAGE_NAME(SOAR)
+    FF_TEST_PACKAGE_NAME(SORCERY)
+    FF_TEST_PACKAGE_NAME(WINGET)
+    FF_TEST_PACKAGE_NAME(XBPS)
+    #undef FF_TEST_PACKAGE_NAME
 
-    if (options->combined != defaultOptions.combined)
-        yyjson_mut_obj_add_bool(doc, module, "combined", options->combined);
+    yyjson_mut_obj_add_bool(doc, module, "combined", options->combined);
 }
 
-void ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FFPackagesResult counts = {};
     ffStrbufInit(&counts.pacmanBranch);
@@ -492,7 +388,7 @@ void ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yy
     if(error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        return;
+        return false;
     }
 
     yyjson_mut_val* obj = yyjson_mut_obj_add_obj(doc, module, "result");
@@ -535,16 +431,33 @@ void ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yy
     FF_APPEND_PACKAGE_COUNT(scoopGlobal)
     FF_APPEND_PACKAGE_COUNT(snap)
     FF_APPEND_PACKAGE_COUNT(soar)
+    FF_APPEND_PACKAGE_COUNT(kiss)
     FF_APPEND_PACKAGE_COUNT(sorcery)
     FF_APPEND_PACKAGE_COUNT(winget)
     FF_APPEND_PACKAGE_COUNT(xbps)
     yyjson_mut_obj_add_strbuf(doc, obj, "pacmanBranch", &counts.pacmanBranch);
+
+    return true;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitPackagesOptions(FFPackagesOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "󰏖");
+
+    options->disabled = FF_PACKAGES_DISABLE_LIST;
+    options->combined = false;
+}
+
+void ffDestroyPackagesOptions(FFPackagesOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffPackagesModuleInfo = {
     .name = FF_PACKAGES_MODULE_NAME,
     .description = "List installed package managers and count of installed packages",
-    .parseCommandOptions = (void*) ffParsePackagesCommandOptions,
+    .initOptions = (void*) ffInitPackagesOptions,
+    .destroyOptions = (void*) ffDestroyPackagesOptions,
     .parseJsonObject = (void*) ffParsePackagesJsonObject,
     .printModule = (void*) ffPrintPackages,
     .generateJsonResult = (void*) ffGeneratePackagesJsonResult,
@@ -592,6 +505,7 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Number of hpkg-user packages", "hpkg-user"},
         {"Number of pisi packages", "pisi"},
         {"Number of soar packages", "soar"},
+        {"Number of kiss packages", "kiss"},
         {"Total number of all nix packages", "nix-all"},
         {"Total number of all flatpak app packages", "flatpak-all"},
         {"Total number of all brew packages", "brew-all"},
@@ -599,17 +513,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Total number of all hpkg packages", "hpkg-all"},
     }))
 };
-
-void ffInitPackagesOptions(FFPackagesOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "󰏖");
-
-    options->disabled = FF_PACKAGES_DISABLE_LIST;
-    options->combined = false;
-}
-
-void ffDestroyPackagesOptions(FFPackagesOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
