@@ -1,10 +1,10 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/tpm/tpm.h"
 #include "modules/tpm/tpm.h"
-#include "util/stringUtils.h"
 
-void ffPrintTPM(FFTPMOptions* options)
+bool ffPrintTPM(FFTPMOptions* options)
 {
     FFTPMResult result = {
         .version = ffStrbufCreate(),
@@ -15,7 +15,7 @@ void ffPrintTPM(FFTPMOptions* options)
     if(error)
     {
         ffPrintError(FF_TPM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
-        return;
+        return false;
     }
 
     if(options->moduleArgs.outputFormat.length == 0)
@@ -36,44 +36,29 @@ void ffPrintTPM(FFTPMOptions* options)
 
     ffStrbufDestroy(&result.version);
     ffStrbufDestroy(&result.description);
-}
 
-bool ffParseTPMCommandOptions(FFTPMOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_TPM_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
+    return true;
 }
 
 void ffParseTPMJsonObject(FFTPMOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_TPM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_TPM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateTPMJsonConfig(FFTPMOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyTPMOptions))) FFTPMOptions defaultOptions;
-    ffInitTPMOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
-void ffGenerateTPMJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateTPMJsonResult(FF_MAYBE_UNUSED FFTPMOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FFTPMResult result = {
         .version = ffStrbufCreate(),
@@ -84,7 +69,7 @@ void ffGenerateTPMJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* options, yyjson_
     if(error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        return;
+        return false;
     }
 
     yyjson_mut_val* obj = yyjson_mut_obj_add_obj(doc, module, "result");
@@ -93,12 +78,25 @@ void ffGenerateTPMJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* options, yyjson_
 
     ffStrbufDestroy(&result.version);
     ffStrbufDestroy(&result.description);
+
+    return true;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitTPMOptions(FFTPMOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "");
+}
+
+void ffDestroyTPMOptions(FFTPMOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffTPMModuleInfo = {
     .name = FF_TPM_MODULE_NAME,
     .description = "Print info of Trusted Platform Module (TPM) Security Device",
-    .parseCommandOptions = (void*) ffParseTPMCommandOptions,
+    .initOptions = (void*) ffInitTPMOptions,
+    .destroyOptions = (void*) ffDestroyTPMOptions,
     .parseJsonObject = (void*) ffParseTPMJsonObject,
     .printModule = (void*) ffPrintTPM,
     .generateJsonResult = (void*) ffGenerateTPMJsonResult,
@@ -108,14 +106,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"TPM general description", "description"},
     }))
 };
-
-void ffInitTPMOptions(FFTPMOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "");
-}
-
-void ffDestroyTPMOptions(FFTPMOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
