@@ -4,7 +4,7 @@
 
 #define FF_WALLPAPER_MODULE_NAME "Wallpaper"
 
-void ffPrintWallpaper(FFWallpaperOptions* options);
+bool ffPrintWallpaper(FFWallpaperOptions* options);
 void ffInitWallpaperOptions(FFWallpaperOptions* options);
 void ffDestroyWallpaperOptions(FFWallpaperOptions* options);
 
