@@ -2,9 +2,10 @@
 #include "common/jsonconfig.h"
 #include "common/percent.h"
 #include "common/size.h"
+#include "common/FFstrbuf.h"
+#include "common/stringUtils.h"
 #include "detection/zpool/zpool.h"
 #include "modules/zpool/zpool.h"
-#include "util/stringUtils.h"
 
 static void printZpool(FFZpoolOptions* options, FFZpoolResult* result, uint8_t index)
 {
@@ -22,6 +23,7 @@ static void printZpool(FFZpoolOptions* options, FFZpoolResult* result, uint8_t i
         FF_PARSE_FORMAT_STRING_CHECKED(&buffer, &options->moduleArgs.key, ((FFformatarg[]) {
             FF_FORMAT_ARG(index, "index"),
             FF_FORMAT_ARG(result->name, "name"),
+            FF_FORMAT_ARG(result->guid, "guid"),
             FF_FORMAT_ARG(options->moduleArgs.keyIcon, "icon"),
         }));
     }
@@ -29,10 +31,14 @@ static void printZpool(FFZpoolOptions* options, FFZpoolResult* result, uint8_t i
     FF_STRBUF_AUTO_DESTROY usedPretty = ffStrbufCreate();
     ffSizeAppendNum(result->used, &usedPretty);
 
+    FF_STRBUF_AUTO_DESTROY allocatedPretty = ffStrbufCreate();
+    ffSizeAppendNum(result->allocated, &allocatedPretty);
+
     FF_STRBUF_AUTO_DESTROY totalPretty = ffStrbufCreate();
     ffSizeAppendNum(result->total, &totalPretty);
 
-    double bytesPercentage = result->total > 0 ? (double) result->used / (double) result->total * 100.0 : 0;
+    double usedPercentage = result->total > 0 ? (double) result->used / (double) result->total * 100.0 : 0;
+    double allocatedPercentage = result->total > 0 ? (double) result->allocated / (double) result->total * 100.0 : 0;
     FFPercentageTypeFlags percentType = options->percent.type == 0 ? instance.config.display.percentType : options->percent.type;
 
     if(options->moduleArgs.outputFormat.length == 0)
@@ -41,20 +47,31 @@ static void printZpool(FFZpoolOptions* options, FFZpoolResult* result, uint8_t i
 
         ffStrbufClear(&buffer);
         ffStrbufSetF(&buffer, "%s / %s (", usedPretty.chars, totalPretty.chars);
-        ffPercentAppendNum(&buffer, bytesPercentage, options->percent, false, &options->moduleArgs);
+        ffPercentAppendNum(&buffer, usedPercentage, options->percent, false, &options->moduleArgs);
         ffStrbufAppendS(&buffer, ", ");
+        ffPercentAppendNum(&buffer, allocatedPercentage, options->percent, false, &options->moduleArgs);
+        ffStrbufAppendS(&buffer, " allocated, ");
         ffPercentAppendNum(&buffer, result->fragmentation, options->percent, false, &options->moduleArgs);
         ffStrbufAppendF(&buffer, " frag) - %s", result->state.chars);
+        if (result->readOnly)
+            ffStrbufAppendS(&buffer, " [Read-only]");
         ffStrbufPutTo(&buffer, stdout);
     }
     else
     {
-        FF_STRBUF_AUTO_DESTROY bytesPercentageNum = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY usedPercentageNum = ffStrbufCreate();
         if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
-            ffPercentAppendNum(&bytesPercentageNum, bytesPercentage, options->percent, false, &options->moduleArgs);
-        FF_STRBUF_AUTO_DESTROY bytesPercentageBar = ffStrbufCreate();
+            ffPercentAppendNum(&usedPercentageNum, usedPercentage, options->percent, false, &options->moduleArgs);
+        FF_STRBUF_AUTO_DESTROY usedPercentageBar = ffStrbufCreate();
         if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
-            ffPercentAppendBar(&bytesPercentageBar, bytesPercentage, options->percent, &options->moduleArgs);
+            ffPercentAppendBar(&usedPercentageBar, usedPercentage, options->percent, &options->moduleArgs);
+
+        FF_STRBUF_AUTO_DESTROY allocatedPercentageNum = ffStrbufCreate();
+        if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+            ffPercentAppendNum(&allocatedPercentageNum, allocatedPercentage, options->percent, false, &options->moduleArgs);
+        FF_STRBUF_AUTO_DESTROY allocatedPercentageBar = ffStrbufCreate();
+        if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+            ffPercentAppendBar(&allocatedPercentageBar, allocatedPercentage, options->percent, &options->moduleArgs);
 
         FF_STRBUF_AUTO_DESTROY fragPercentageNum = ffStrbufCreate();
         if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
@@ -65,18 +82,23 @@ static void printZpool(FFZpoolOptions* options, FFZpoolResult* result, uint8_t i
 
         FF_PRINT_FORMAT_CHECKED(buffer.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, ((FFformatarg[]) {
             FF_FORMAT_ARG(result->name, "name"),
+            FF_FORMAT_ARG(result->guid, "guid"),
             FF_FORMAT_ARG(result->state, "state"),
             FF_FORMAT_ARG(usedPretty, "size-used"),
+            FF_FORMAT_ARG(allocatedPretty, "size-allocated"),
             FF_FORMAT_ARG(totalPretty, "size-total"),
-            FF_FORMAT_ARG(bytesPercentageNum, "size-percentage"),
+            FF_FORMAT_ARG(usedPercentageNum, "used-percentage"),
+            FF_FORMAT_ARG(allocatedPercentageNum, "allocated-percentage"),
             FF_FORMAT_ARG(fragPercentageNum, "frag-percentage"),
-            FF_FORMAT_ARG(bytesPercentageBar, "size-percentage-bar"),
+            FF_FORMAT_ARG(usedPercentageBar, "used-percentage-bar"),
+            FF_FORMAT_ARG(allocatedPercentageBar, "allocated-percentage-bar"),
             FF_FORMAT_ARG(fragPercentageBar, "frag-percentage-bar"),
+            FF_FORMAT_ARG(result->readOnly, "is-readonly"),
         }));
     }
 }
 
-void ffPrintZpool(FFZpoolOptions* options)
+bool ffPrintZpool(FFZpoolOptions* options)
 {
     FF_LIST_AUTO_DESTROY results = ffListCreate(sizeof(FFZpoolResult));
 
@@ -85,12 +107,12 @@ void ffPrintZpool(FFZpoolOptions* options)
     if (error)
     {
         ffPrintError(FF_ZPOOL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
-        return;
+        return false;
     }
     if(results.length == 0)
     {
         ffPrintError(FF_ZPOOL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", "No zpool found");
-        return;
+        return false;
     }
 
     for(uint32_t i = 0; i < results.length; i++)
@@ -105,52 +127,33 @@ void ffPrintZpool(FFZpoolOptions* options)
         ffStrbufDestroy(&result->name);
         ffStrbufDestroy(&result->state);
     }
-}
-
-bool ffParseZpoolCommandOptions(FFZpoolOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_ZPOOL_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    if (ffPercentParseCommandOptions(key, subKey, value, &options->percent))
-        return true;
-
-    return false;
+    return true;
 }
 
 void ffParseZpoolJsonObject(FFZpoolOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
         if (ffPercentParseJsonObject(key, val, &options->percent))
             continue;
 
-        ffPrintError(FF_ZPOOL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_ZPOOL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateZpoolJsonConfig(FFZpoolOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyZpoolOptions))) FFZpoolOptions defaultOptions;
-    ffInitZpoolOptions(&defaultOptions);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
-
-    ffPercentGenerateJsonConfig(doc, module, defaultOptions.percent, options->percent);
+    ffPercentGenerateJsonConfig(doc, module, options->percent);
 }
 
-void ffGenerateZpoolJsonResult(FF_MAYBE_UNUSED FFZpoolOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateZpoolJsonResult(FF_MAYBE_UNUSED FFZpoolOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FF_LIST_AUTO_DESTROY results = ffListCreate(sizeof(FFZpoolResult));
 
@@ -158,7 +161,7 @@ void ffGenerateZpoolJsonResult(FF_MAYBE_UNUSED FFZpoolOptions* options, yyjson_m
     if (error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        return;
+        return false;
     }
 
     yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "result");
@@ -168,10 +171,15 @@ void ffGenerateZpoolJsonResult(FF_MAYBE_UNUSED FFZpoolOptions* options, yyjson_m
         yyjson_mut_val* obj = yyjson_mut_arr_add_obj(doc, arr);
         yyjson_mut_obj_add_strbuf(doc, obj, "name", &zpool->name);
         yyjson_mut_obj_add_strbuf(doc, obj, "state", &zpool->state);
+        yyjson_mut_obj_add_uint(doc, obj, "guid", zpool->guid);
         yyjson_mut_obj_add_uint(doc, obj, "used", zpool->used);
+        yyjson_mut_obj_add_uint(doc, obj, "allocated", zpool->allocated);
         yyjson_mut_obj_add_uint(doc, obj, "total", zpool->total);
-        yyjson_mut_obj_add_uint(doc, obj, "version", zpool->version);
-        yyjson_mut_obj_add_real(doc, obj, "fragmentation", zpool->fragmentation);
+        if (zpool->fragmentation != -DBL_MAX)
+            yyjson_mut_obj_add_real(doc, obj, "fragmentation", zpool->fragmentation);
+        else
+            yyjson_mut_obj_add_null(doc, obj, "fragmentation");
+        yyjson_mut_obj_add_bool(doc, obj, "readOnly", zpool->readOnly);
     }
 
     FF_LIST_FOR_EACH(FFZpoolResult, zpool, results)
@@ -179,31 +187,11 @@ void ffGenerateZpoolJsonResult(FF_MAYBE_UNUSED FFZpoolOptions* options, yyjson_m
         ffStrbufDestroy(&zpool->name);
         ffStrbufDestroy(&zpool->state);
     }
+    return true;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
-    .name = FF_ZPOOL_MODULE_NAME,
-    .description = "Print ZFS storage pools",
-    .parseCommandOptions = (void*) ffParseZpoolCommandOptions,
-    .parseJsonObject = (void*) ffParseZpoolJsonObject,
-    .printModule = (void*) ffPrintZpool,
-    .generateJsonResult = (void*) ffGenerateZpoolJsonResult,
-    .generateJsonConfig = (void*) ffGenerateZpoolJsonConfig,
-    .formatArgs = FF_FORMAT_ARG_LIST(((FFModuleFormatArg[]) {
-        {"Zpool name", "name"},
-        {"Zpool state", "state"},
-        {"Size used", "used"},
-        {"Size total", "total"},
-        {"Size percentage num", "used-percentage"},
-        {"Fragmentation percentage num", "fragmentation-percentage"},
-        {"Size percentage bar", "used-percentage-bar"},
-        {"Fragmentation percentage bar", "fragmentation-percentage-bar"},
-    }))
-};
-
 void ffInitZpoolOptions(FFZpoolOptions* options)
 {
-    options->moduleInfo = ffModuleInfo;
     ffOptionInitModuleArg(&options->moduleArgs, "󱑛");
     options->percent = (FFPercentageModuleConfig) { 50, 80, 0 };
 }
@@ -212,3 +200,29 @@ void ffDestroyZpoolOptions(FFZpoolOptions* options)
 {
     ffOptionDestroyModuleArg(&options->moduleArgs);
 }
+
+FFModuleBaseInfo ffZpoolModuleInfo = {
+    .name = FF_ZPOOL_MODULE_NAME,
+    .description = "Print ZFS storage pools",
+    .initOptions = (void*) ffInitZpoolOptions,
+    .destroyOptions = (void*) ffDestroyZpoolOptions,
+    .parseJsonObject = (void*) ffParseZpoolJsonObject,
+    .printModule = (void*) ffPrintZpool,
+    .generateJsonResult = (void*) ffGenerateZpoolJsonResult,
+    .generateJsonConfig = (void*) ffGenerateZpoolJsonConfig,
+    .formatArgs = FF_FORMAT_ARG_LIST(((FFModuleFormatArg[]) {
+        {"Zpool name", "name"},
+        {"Zpool guid", "guid"},
+        {"Zpool state", "state"},
+        {"Size used", "used"},
+        {"Size allocated", "allocated"},
+        {"Size total", "total"},
+        {"Size used percentage num", "used-percentage"},
+        {"Size allocated percentage num", "allocated-percentage"},
+        {"Fragmentation percentage num", "fragmentation-percentage"},
+        {"Size used percentage bar", "used-percentage-bar"},
+        {"Size allocated percentage bar", "allocated-percentage-bar"},
+        {"Fragmentation percentage bar", "fragmentation-percentage-bar"},
+        {"Is read-only", "is-readonly"},
+    }))
+};
